@@ -92,6 +92,7 @@ module Kramdown
       def convert_codeblock(el, indent)
         attr = el.attr.dup
         lang = extract_code_language!(attr)
+        lang = el.options[:lang] if el.options.has_key?(:lang)
         highlighted_code = highlight_code(el.value, lang, :block)
 
         if highlighted_code
@@ -112,7 +113,7 @@ module Kramdown
             end
           end
           code_attr = {}
-          code_attr['class'] = "language-#{lang}" if lang
+          code_attr['class'] = "language-#{lang.sub(/\?.*$/, '')}" if lang
           "#{' '*indent}<pre#{html_attributes(attr)}><code#{html_attributes(code_attr)}>#{result}\n</code></pre>\n"
         end
       end
@@ -444,9 +445,11 @@ module Kramdown
             insert_space = false
           end
 
-          para.children << Element.new(:raw, FOOTNOTE_BACKLINK_FMT % [insert_space ? ' ' : '', name, backlink_text])
-          (1..repeat).each do |index|
-            para.children << Element.new(:raw, FOOTNOTE_BACKLINK_FMT % [" ", "#{name}:#{index}", "#{backlink_text}<sup>#{index+1}</sup>"])
+          unless @options[:footnote_backlink].empty?
+            para.children << Element.new(:raw, FOOTNOTE_BACKLINK_FMT % [insert_space ? ' ' : '', name, backlink_text])
+            (1..repeat).each do |index|
+              para.children << Element.new(:raw, FOOTNOTE_BACKLINK_FMT % [" ", "#{name}:#{index}", "#{backlink_text}<sup>#{index+1}</sup>"])
+            end
           end
 
           ol.children << Element.new(:raw, convert(li, 4))
