@@ -1,13 +1,14 @@
 # -*- coding: utf-8 -*-
 #
 #--
-# Copyright (C) 2009-2014 Thomas Leitner <t_leitner@gmx.at>
+# Copyright (C) 2009-2015 Thomas Leitner <t_leitner@gmx.at>
 #
 # This file is part of kramdown which is licensed under the MIT.
 #++
 #
 
 require 'set'
+require 'kramdown/converter'
 
 module Kramdown
 
@@ -83,7 +84,12 @@ module Kramdown
       def convert_codeblock(el, opts)
         show_whitespace = el.attr['class'].to_s =~ /\bshow-whitespaces\b/
         lang = extract_code_language(el.attr)
-        if show_whitespace || lang
+
+        if @options[:syntax_highlighter] == :minted &&
+            (highlighted_code = highlight_code(el.value, lang, :block))
+          @data[:packages] << 'minted'
+          "#{latex_link_target(el)}#{highlighted_code}\n"
+        elsif show_whitespace || lang
           options = []
           options << "showspaces=%s,showtabs=%s" % (show_whitespace ? ['true', 'true'] : ['false', 'false'])
           options << "language=#{lang}" if lang
@@ -225,7 +231,14 @@ module Kramdown
       end
 
       def convert_codespan(el, opts)
-        "{\\tt #{latex_link_target(el)}#{escape(el.value)}}"
+        lang = extract_code_language(el.attr)
+        if @options[:syntax_highlighter] == :minted &&
+            (highlighted_code = highlight_code(el.value, lang, :span))
+          @data[:packages] << 'minted'
+          "#{latex_link_target(el)}#{highlighted_code}"
+        else
+          "\\texttt{#{latex_link_target(el)}#{escape(el.value)}}"
+        end
       end
 
       def convert_footnote(el, opts)
