@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 #--
-# Copyright (C) 2009-2014 Thomas Leitner <t_leitner@gmx.at>
+# Copyright (C) 2009-2015 Thomas Leitner <t_leitner@gmx.at>
 #
 # This file is part of kramdown which is licensed under the MIT.
 #++
@@ -9,7 +9,8 @@
 
 require 'prawn'
 require 'prawn/table'
-require 'kramdown/utils/entities'
+require 'kramdown/converter'
+require 'kramdown/utils'
 require 'open-uri'
 
 module Kramdown
