@@ -1,25 +1,14 @@
 # -*- coding: utf-8 -*-
 #
 #--
-# Copyright (C) 2009-2012 Thomas Leitner <t_leitner@gmx.at>
+# Copyright (C) 2009-2015 Thomas Leitner <t_leitner@gmx.at>
 #
-# This file is part of kramdown.
-#
-# kramdown is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# This file is part of kramdown which is licensed under the MIT.
 #++
 #
 
+require 'yaml'
+
 module Kramdown
 
   # This module defines all options that are used by parsers and/or converters as well as providing
@@ -59,6 +48,7 @@ module Kramdown
     # suffices. A block needs to be specified when using type 'Object' and it has to cope with
     # a value given as string and as the opaque type.
     def self.define(name, type, default, desc, &block)
+      name = name.to_sym
       raise ArgumentError, "Option name #{name} is already used" if @options.has_key?(name)
       raise ArgumentError, "Invalid option type #{type} specified" if !ALLOWED_TYPES.include?(type)
       raise ArgumentError, "Invalid type for default value" if !(type === default) && !default.nil?
@@ -73,7 +63,7 @@ module Kramdown
 
     # Return +true+ if an option called +name+ is defined.
     def self.defined?(name)
-      @options.has_key?(name)
+      @options.has_key?(name.to_sym)
     end
 
     # Return a Hash with the default values for all options.
@@ -88,8 +78,8 @@ module Kramdown
     def self.merge(hash)
       temp = defaults
       hash.each do |k,v|
-        next unless @options.has_key?(k)
-        temp[k] = parse(k, v)
+        k = k.to_sym
+        @options.has_key?(k) ? temp[k] = parse(k, v) : temp[k] = v
       end
       temp
     end
@@ -100,6 +90,7 @@ module Kramdown
     # If +data+ already has the correct type, it is just returned. Otherwise it is converted to a
     # String and then to the correct type.
     def self.parse(name, data)
+      name = name.to_sym
       raise ArgumentError, "No option named #{name} defined" if !@options.has_key?(name)
       if !(@options[name].type === data)
         data = data.to_s
@@ -110,9 +101,7 @@ module Kramdown
                elsif @options[name].type == Float
                  Float(data) rescue raise Kramdown::Error, "Invalid float value for option '#{name}': '#{data}'"
                elsif @options[name].type == Symbol
-                 data.strip!
-                 data = data[1..-1] if data[0] == ?:
-                 (data.empty? || data == 'nil' ? nil : data.to_sym)
+                 str_to_sym(data)
                elsif @options[name].type == Boolean
                  data.downcase.strip != 'false' && !data.empty?
                end
@@ -121,6 +110,17 @@ module Kramdown
       data
     end
 
+    # Converts the given String +data+ into a Symbol or +nil+ with the
+    # following provisions:
+    #
+    # - A leading colon is stripped from the string.
+    # - An empty value or a value equal to "nil" results in +nil+.
+    def self.str_to_sym(data)
+      data = data.strip
+      data = data[1..-1] if data[0] == ?:
+      (data.empty? || data == 'nil' ? nil : data.to_sym)
+    end
+
     # ----------------------------
     # :section: Option Validators
     #
@@ -146,6 +146,23 @@ module Kramdown
       val
     end
 
+    # Ensures that the option value +val+ for the option called +name+ is a valid hash. The
+    # parameter +val+ can be
+    #
+    # - a hash in YAML format
+    # - or a Ruby Hash object.
+    def self.simple_hash_validator(val, name)
+      if String === val
+        begin
+          val = YAML.load(val)
+        rescue RuntimeError, ArgumentError, SyntaxError
+          raise Kramdown::Error, "Invalid YAML value for option #{name}"
+        end
+      end
+      raise Kramdown::Error, "Invalid type #{val.class} for option #{name}" if !(Hash === val)
+      val
+    end
+
     # ----------------------------
     # :section: Option Definitions
     #
@@ -155,6 +172,7 @@ module Kramdown
 
     define(:template, String, '', <<EOF)
 The name of an ERB template file that should be used to wrap the output
+or the ERB template itself.
 
 This is used to wrap the output in an environment so that the output can
 be used as a stand-alone document. For example, an HTML template would
@@ -163,10 +181,13 @@ valid HTML file. If no template is specified, the output will be just
 the converted text.
 
 When resolving the template file, the given template name is used first.
-If such a file is not found, the converter extension is appended. If the
-file still cannot be found, the templates name is interpreted as a
-template name that is provided by kramdown (without the converter
-extension).
+If such a file is not found, the converter extension (the same as the
+converter name) is appended. If the file still cannot be found, the
+templates name is interpreted as a template name that is provided by
+kramdown (without the converter extension). If the file is still not
+found, the template name is checked if it starts with 'string://' and if
+it does, this prefix is removed and the rest is used as template
+content.
 
 kramdown provides a default template named 'document' for each converter.
 
@@ -182,10 +203,24 @@ generated if no ID is explicitly specified.
 
 Default: true
 Used by: HTML/Latex converter
+EOF
+
+    define(:auto_id_stripping, Boolean, false, <<EOF)
+Strip all formatting from header text for automatic ID generation
+
+If this option is `true`, only the text elements of a header are used
+for generating the ID later (in contrast to just using the raw header
+text line).
+
+This option will be removed in version 2.0 because this will be the
+default then.
+
+Default: false
+Used by: kramdown parser
 EOF
 
     define(:auto_id_prefix, String, '', <<EOF)
-Prefix used for automatically generated heaer IDs
+Prefix used for automatically generated header IDs
 
 This option can be used to set a prefix for the automatically generated
 header IDs so that there is no conflict when rendering multiple kramdown
@@ -194,6 +229,20 @@ contain characters that are valid in an ID!
 
 Default: ''
 Used by: HTML/Latex converter
+EOF
+
+    define(:transliterated_header_ids, Boolean, false, <<EOF)
+Transliterate the header text before generating the ID
+
+Only ASCII characters are used in headers IDs. This is not good for
+languages with many non-ASCII characters. By enabling this option
+the header text is transliterated to ASCII as good as possible so that
+the resulting header ID is more useful.
+
+The stringex library needs to be installed for this feature to work!
+
+Default: false
+Used by: HTML/Latex converter
 EOF
 
     define(:parse_block_html, Boolean, false, <<EOF)
@@ -233,6 +282,29 @@ Default: false
 Used by: kramdown parser
 EOF
 
+    define(:link_defs, Object, {}, <<EOF) do |val|
+Pre-defines link definitions
+
+This option can be used to pre-define link definitions. The value needs
+to be a Hash where the keys are the link identifiers and the values are
+two element Arrays with the link URL and the link title.
+
+If the value is a String, it has to contain a valid YAML hash and the
+hash has to follow the above guidelines.
+
+Default: {}
+Used by: kramdown parser
+EOF
+      val = simple_hash_validator(val, :link_defs)
+      val.each do |k,v|
+        if !(Array === v) || v.size > 2 || v.size < 1
+          raise Kramdown::Error, "Invalid structure for hash value of option #{name}"
+        end
+        v << nil if v.size == 1
+      end
+      val
+    end
+
     define(:footnote_nr, Integer, 1, <<EOF)
 The number of the first footnote
 
@@ -285,12 +357,21 @@ The tab width used in highlighted code
 Used by: HTML converter
 EOF
 
-    define(:coderay_bold_every, Integer, 10, <<EOF)
+    define(:coderay_bold_every, Object, 10, <<EOF) do |val|
 Defines how often a line number should be made bold
 
+Can either be an integer or false (to turn off bold line numbers
+completely).
+
 Default: 10
 Used by: HTML converter
 EOF
+      if val == false || val.to_s == 'false'
+        false
+      else
+        Integer(val.to_s) rescue raise Kramdown::Error, "Invalid value for option 'coderay_bold_every'"
+      end
+end
 
     define(:coderay_css, Symbol, :style, <<EOF)
 Defines how the highlighted code gets styled
@@ -337,7 +418,8 @@ specified levels are used for the table of contents.
 Default: 1..6
 Used by: HTML/Latex converter
 EOF
-      if String === val
+      case val
+      when String
         if val =~ /^(\d)\.\.(\d)$/
           val = Range.new($1.to_i, $2.to_i).to_a
         elsif val =~ /^\d(?:,\d)*$/
@@ -345,7 +427,7 @@ EOF
         else
           raise Kramdown::Error, "Invalid syntax for option toc_levels"
         end
-      elsif Array === val
+      when Array, Range
         val = val.map {|s| s.to_i}.uniq
       else
         raise Kramdown::Error, "Invalid type #{val.class} for option toc_levels"
@@ -420,6 +502,95 @@ level 1 will be used. If c+n is greater than 6, level 6 will be used.
 
 Default: 0
 Used by: HTML converter, Kramdown converter, Latex converter
+EOF
+
+    define(:hard_wrap, Boolean, true, <<EOF)
+Interprets line breaks literally
+
+Insert HTML `<br />` tags inside paragraphs where the original Markdown
+document had newlines (by default, Markdown ignores these newlines).
+
+Default: true
+Used by: GFM parser
+EOF
+
+    define(:syntax_highlighter, Symbol, :coderay, <<EOF)
+Set the syntax highlighter
+
+Specifies the syntax highlighter that should be used for highlighting
+code blocks and spans. If this option is set to +nil+, no syntax
+highlighting is done.
+
+Options for the syntax highlighter can be set with the
+syntax_highlighter_opts configuration option.
+
+Default: coderay
+Used by: HTML/Latex converter
+EOF
+
+    define(:syntax_highlighter_opts, Object, {}, <<EOF) do |val|
+Set the syntax highlighter options
+
+Specifies options for the syntax highlighter set via the
+syntax_highlighter configuration option.
+
+The value needs to be a hash with key-value pairs that are understood by
+the used syntax highlighter.
+
+Default: {}
+Used by: HTML/Latex converter
+EOF
+      val = simple_hash_validator(val, :syntax_highlighter_opts)
+      val.keys.each do |k|
+        val[k.kind_of?(String) ? str_to_sym(k) : k] = val.delete(k)
+      end
+      val
+    end
+
+    define(:math_engine, Symbol, :mathjax, <<EOF)
+Set the math engine
+
+Specifies the math engine that should be used for converting math
+blocks/spans. If this option is set to +nil+, no math engine is used and
+the math blocks/spans are output as is.
+
+Options for the selected math engine can be set with the
+math_engine_opts configuration option.
+
+Default: mathjax
+Used by: HTML converter
+EOF
+
+    define(:math_engine_opts, Object, {}, <<EOF) do |val|
+Set the math engine options
+
+Specifies options for the math engine set via the math_engine
+configuration option.
+
+The value needs to be a hash with key-value pairs that are understood by
+the used math engine.
+
+Default: {}
+Used by: HTML converter
+EOF
+      val = simple_hash_validator(val, :math_engine_opts)
+      val.keys.each do |k|
+        val[k.kind_of?(String) ? str_to_sym(k) : k] = val.delete(k)
+      end
+      val
+    end
+
+    define(:footnote_backlink, String, '&#8617;', <<EOF)
+Defines the text that should be used for the footnote backlinks
+
+The footnote backlink is just text, so any special HTML characters will
+be escaped.
+
+If the footnote backlint text is an empty string, no footnote backlinks
+will be generated.
+
+Default: '&8617;'
+Used by: HTML converter
 EOF
 
   end
