@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 #--
-# Copyright (C) 2009-2013 Thomas Leitner <t_leitner@gmx.at>
+# Copyright (C) 2009-2015 Thomas Leitner <t_leitner@gmx.at>
 #
 # This file is part of kramdown which is licensed under the MIT.
 #++
@@ -15,8 +15,9 @@ module Kramdown
 
       # Parse the horizontal rule at the current location.
       def parse_horizontal_rule
+        start_line_number = @src.current_line_number
         @src.pos += @src.matched_size
-        @tree.children << new_block_el(:hr)
+        @tree.children << new_block_el(:hr, nil, nil, :location => start_line_number)
         true
       end
       define_parser(:horizontal_rule, HR_START)
