@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 #--
-# Copyright (C) 2009-2014 Thomas Leitner <t_leitner@gmx.at>
+# Copyright (C) 2009-2015 Thomas Leitner <t_leitner@gmx.at>
 #
 # This file is part of kramdown which is licensed under the MIT.
 #++
@@ -123,7 +123,7 @@ module Kramdown
 
       SQ_RULES = [
                   [/("|')(?=[_*]{1,2}\S)/, [:lquote1]],
-                  [/("|')(?=#{SQ_PUNCT}\B)/, [:rquote1]],
+                  [/("|')(?=#{SQ_PUNCT}(?!\.\.)\B)/, [:rquote1]],
                   # Special case for double sets of quotes, e.g.:
                   #   <p>He said, "'Quoted' words in a larger quote."</p>
                   [/(\s?)"'(?=\w)/, [1, :ldquo, :lsquo]],
